package pm.masinacudinti;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothSocket;
import android.graphics.drawable.Drawable;
import android.support.v7.app.ActionBarActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import java.io.IOException;
import java.lang.reflect.Method;
import java.util.UUID;


public class MainActivity extends ActionBarActivity {
    BluetoothAdapter mBluetoothAdapter;
    static final UUID BT_UUID = UUID.fromString("00001101-0000-1000-8000-00805F9B34FB");
    static final String MAC = "20:15:03:17:14:89";
    BluetoothSocket mSocket;
    ConnectedThread mConnectedThread;
    boolean mIsConnected;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mSocket = null;
        mIsConnected = false;

        mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();


        if (!mBluetoothAdapter.isEnabled()) {
            // If Bluetooth is disabled.
            Log.e("BT_DISABLED", "Bluetooth is disabled on the Android device.");
        }

        ImageView statusImg = (ImageView)findViewById(R.id.status);
        statusImg.setImageResource(R.drawable.not_ok);

        statusImg.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (mIsConnected) {
                    v.setVisibility(View.GONE);
                    TextView text = (TextView) findViewById(R.id.statusText);
                    text.setVisibility(View.GONE);
                    RelativeLayout controls = (RelativeLayout) findViewById(R.id.controls);
                    controls.setVisibility(View.VISIBLE);
                }
            }
        });

        // Connect to the HC-06 module
        BluetoothDevice device = null;
        device = mBluetoothAdapter.getRemoteDevice(MAC);

        if (device == null) {
            Toast toast = Toast.makeText(this, "Couldn't find HC-06 module.", Toast.LENGTH_LONG);
            return;
        }

        (new ConnectThread(device, MainActivity.this)).start();

        Button button;

        //while (!mIsConnected);

        // Set listener for up_button
        button = (Button) this.findViewById(R.id.up_button);
        button.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                v.onTouchEvent(event);
                if (event.getAction() == MotionEvent.ACTION_UP) {
                    mConnectedThread.write("0".getBytes());
                    return true;
                }
                if (event.getAction() == MotionEvent.ACTION_DOWN) {
                    mConnectedThread.write("w".getBytes());
                    return true;
                }
                return false;
            }
        });
        // Set listener for down_button
        button = (Button) this.findViewById(R.id.down_button);
        button.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                v.onTouchEvent(event);
                if (event.getAction() == MotionEvent.ACTION_UP) {
                    mConnectedThread.write("0".getBytes());
                    return true;
                }
                if (event.getAction() == MotionEvent.ACTION_DOWN) {
                    mConnectedThread.write("x".getBytes());
                    return true;
                }
                return false;
            }
        });
        // Set listener for left_button
        button = (Button) this.findViewById(R.id.left_button);
        button.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                v.onTouchEvent(event);
                if (event.getAction() == MotionEvent.ACTION_UP) {
                    mConnectedThread.write("0".getBytes());
                    return true;
                }
                if (event.getAction() == MotionEvent.ACTION_DOWN) {
                    mConnectedThread.write("a".getBytes());
                    return true;
                }
                return false;
            }
        });
        // Set listener for right_button
        button = (Button) this.findViewById(R.id.right_button);
        button.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                v.onTouchEvent(event);
                if (event.getAction() == MotionEvent.ACTION_UP) {
                    mConnectedThread.write("0".getBytes());
                    return true;
                }
                if (event.getAction() == MotionEvent.ACTION_DOWN) {
                    mConnectedThread.write("d".getBytes());
                    return true;
                }
                return false;
            }
        });
        // Set listener for up_left_button
        button = (Button) this.findViewById(R.id.up_left_button);
        button.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                v.onTouchEvent(event);
                if (event.getAction() == MotionEvent.ACTION_UP) {
                    mConnectedThread.write("0".getBytes());
                    return true;
                }
                if (event.getAction() == MotionEvent.ACTION_DOWN) {
                    mConnectedThread.write("q".getBytes());
                    return true;
                }
                return false;
            }
        });
        // Set listener for up_right_button
        button = (Button) this.findViewById(R.id.up_right_button);
        button.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                v.onTouchEvent(event);
                if (event.getAction() == MotionEvent.ACTION_UP) {
                    mConnectedThread.write("0".getBytes());
                    return true;
                }
                if (event.getAction() == MotionEvent.ACTION_DOWN) {
                    mConnectedThread.write("e".getBytes());
                    return true;
                }
                return false;
            }
        });
        // Set listener for down_left_button
        button = (Button) this.findViewById(R.id.down_left_button);
        button.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                v.onTouchEvent(event);
                if (event.getAction() == MotionEvent.ACTION_UP) {
                    mConnectedThread.write("0".getBytes());
                    return true;
                }
                if (event.getAction() == MotionEvent.ACTION_DOWN) {
                    mConnectedThread.write("z".getBytes());
                    return true;
                }
                return false;
            }
        });
        // Set listener for down_right_button
        button = (Button) this.findViewById(R.id.down_right_button);
        button.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                v.onTouchEvent(event);
                if (event.getAction() == MotionEvent.ACTION_UP) {
                    mConnectedThread.write("0".getBytes());
                    return true;
                }
                if (event.getAction() == MotionEvent.ACTION_DOWN) {
                    mConnectedThread.write("c".getBytes());
                    return true;
                }
                return false;
            }
        });

        button = (Button) this.findViewById(R.id.stop);
        button.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mConnectedThread.write("0".getBytes());
            }
        });
    }


    void setSocket(BluetoothSocket sock) {
        mSocket = sock;
    }

    void setIsConnected(boolean val) {
        mIsConnected = val;
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
